Automated Project Initialization 🐍💚💙 
---
An automated setup for Django project with Tailwind. Handles all setup and configuration automatically.✨

<p align="left">
  <a href="https://skillicons.dev">
    <img src="https://skillicons.dev/icons?i=django,tailwindcss,python" />
  </a>
</p>

## Getting Started 💙
- 👀 Before you dive in, make sure that you have Node.js, Git, and Python installed on your computer.
- Create a Project Folder: Create a folder for your Django project.

## Install the Package 

Open your terminal and install the package using pip:
```bash
pip install django_tailwindcss_automated
```

## Run the Script

In your terminal, run the following script to automate the setup:
```bash
automate-django-tailwind
```

## Start the Development Server

Open another terminal and navigate to the 'project_name' directory within your project folder:
```bash
cd app
```

## Then start the development server


```bash
python manage.py runserver
```

![Alt Text](img.png)


## Happy Coding!!
